GoalFeedbackStream

Struct GoalFeedbackStream 

pub struct GoalFeedbackStream<'a, A: RosAction, const GOAL_BUF: usize = { crate::config::DEFAULT_RX_BUF_SIZE }, const RESULT_BUF: usize = { crate::config::DEFAULT_RX_BUF_SIZE }, const FEEDBACK_BUF: usize = { crate::config::DEFAULT_RX_BUF_SIZE }> { /* private fields */ }
A goal-filtered feedback stream.

Created by ActionClient::feedback_stream_for(). Only yields feedback messages matching the specified goal ID.

Implementations

Source

impl<A: RosAction, const GOAL_BUF: usize, const RESULT_BUF: usize, const FEEDBACK_BUF: usize> GoalFeedbackStream<'_, A, GOAL_BUF, RESULT_BUF, FEEDBACK_BUF>

pub async fn recv(&mut self) -> Option<Result<A::Feedback, NodeError>>

Async: wait for the next feedback message for this goal (no futures dependency needed).

When the stream feature is enabled, prefer StreamExt::next() or TryStreamExt::try_next() for combinator support.

pub fn wait_next( &mut self, executor: &mut Executor, timeout: Duration, ) -> Result<Option<A::Feedback>, NodeError>

Sync: wait for the next feedback message for this goal, spinning the executor.