RawGoalResponseCallback

Type Alias RawGoalResponseCallback 

pub type RawGoalResponseCallback = unsafe extern "C" fn(goal_id: *const GoalId, accepted: bool, context: *mut c_void);
Raw action client goal-response callback.

Called when the action server accepts or rejects a goal.

Safety

  • goal_id is valid for the duration of the call

accepted is true if the goal was accepted, false if rejected.