pub struct PublisherHandle<M> { /* private fields */ }Expand description
Handle to a publisher
This is a lightweight handle that references a publisher registered
with a Node. The type parameter M ensures type safety when publishing.