pub struct SubscriptionHandle<M> { /* private fields */ }Expand description
Handle to a subscriber
This is a lightweight handle that references a subscriber registered
with a Node. The type parameter M ensures type safety when receiving.