pub struct TimerHandle<C = TimerCallbackFn> { /* private fields */ }Expand description
A handle to a timer stored in a node
This is a lightweight handle that references a timer by index.
The actual timer state is stored in the ConnectedNode.
Type Parameters
C: Callback type marker (function pointer or boxed)
Implementations