pub unsafe fn make_waker(state: *const CWakeState) -> WakerExpand description
Build a Waker that calls state.fn_ptr(state.ctx) on wake.
Safety
statemust point to a validCWakeState.statemust remain at the same address for as long as the returned Waker (and any clones a backend stashes) lives.- If a backend dispatches wakes from another thread,
state’sctxmust be safe to read from that thread (seeCWakeStateSend/Syncdiscussion).