pub type RawGoalResponseCallback = unsafe extern "C" fn(goal_id: *const GoalId, accepted: bool, context: *mut c_void);Expand description
Raw action client goal-response callback.
Called when the action server accepts or rejects a goal.
Safety
goal_idis valid for the duration of the call
accepted is true if the goal was accepted, false if rejected.